@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2012 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2014 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -113,21 +113,7 @@ public class MyActivator extends HousekeepingActivator {
         // register the http info/sso servlet
         final String alias = getFromConfig("com.openexchange.upsell.multiple.servlet");
         {
-            // In-place checker
-            class EmptyCecker {
-                boolean isEmpty(final String string) {
-                    if (null == string) {
-                        return true;
-                    }
-                    final int len = string.length();
-                    boolean isWhitespace = true;
-                    for (int i = 0; isWhitespace && i < len; i++) {
-                        isWhitespace = com.openexchange.java.Strings.isWhitespace(string.charAt(i));
-                    }
-                    return isWhitespace;
-                }
-            }
-            if (new EmptyCecker().isEmpty(alias)) {
+            if (com.openexchange.java.Strings.isEmpty(alias)) {
                 registry.clearRegistry();
                 final IllegalStateException e = new IllegalStateException("Missing property in \"com.openexchange.upsell.multiple.servlet\" configuration or missing file \"upsell.properties\".");
                 LOG.error("", e);
